# MieLib

Python library with many Mie-related functions for optics and acoustics. In particular:
- Scattering Mie coefficients for isotropic spheres:
    -  Acoustic Mie coefficients based on Phys. Rev. Lett. 123, 183901 (2019) (see SM)
    - Optics Mie coefficients based on Bohren Huffmann book.
- Scalar spherical harmonics
- Vector spherical harmonics (complex and real)

## Instalation

From [PYPI/mielib](https://pypi.org/project/mielib/):
```
pip install mielib
```

## Examples

See examples folder with Jupyter Notebooks.

## ToDo

* Make tests
* Setup github actions
* Search for complex poles of Mie scattering coefficients

## Credits
Ivan Toftul 

`toftul.ivan@gmail.com`
